import { aG as __vitePreload, aF as defineStore, r as ref, a as computed, W as inject, aR as quasarKey } from "./index.6081da41.js";
/*! Capacitor: https://capacitorjs.com/ - MIT License */
const createCapacitorPlatforms = (win) => {
  const defaultPlatformMap = /* @__PURE__ */ new Map();
  defaultPlatformMap.set("web", { name: "web" });
  const capPlatforms = win.CapacitorPlatforms || {
    currentPlatform: { name: "web" },
    platforms: defaultPlatformMap
  };
  const addPlatform = (name2, platform) => {
    capPlatforms.platforms.set(name2, platform);
  };
  const setPlatform = (name2) => {
    if (capPlatforms.platforms.has(name2)) {
      capPlatforms.currentPlatform = capPlatforms.platforms.get(name2);
    }
  };
  capPlatforms.addPlatform = addPlatform;
  capPlatforms.setPlatform = setPlatform;
  return capPlatforms;
};
const initPlatforms = (win) => win.CapacitorPlatforms = createCapacitorPlatforms(win);
const CapacitorPlatforms = /* @__PURE__ */ initPlatforms(typeof globalThis !== "undefined" ? globalThis : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : typeof global !== "undefined" ? global : {});
CapacitorPlatforms.addPlatform;
CapacitorPlatforms.setPlatform;
var ExceptionCode;
(function(ExceptionCode2) {
  ExceptionCode2["Unimplemented"] = "UNIMPLEMENTED";
  ExceptionCode2["Unavailable"] = "UNAVAILABLE";
})(ExceptionCode || (ExceptionCode = {}));
class CapacitorException extends Error {
  constructor(message, code, data) {
    super(message);
    this.message = message;
    this.code = code;
    this.data = data;
  }
}
const getPlatformId = (win) => {
  var _a, _b;
  if (win === null || win === void 0 ? void 0 : win.androidBridge) {
    return "android";
  } else if ((_b = (_a = win === null || win === void 0 ? void 0 : win.webkit) === null || _a === void 0 ? void 0 : _a.messageHandlers) === null || _b === void 0 ? void 0 : _b.bridge) {
    return "ios";
  } else {
    return "web";
  }
};
const createCapacitor = (win) => {
  var _a, _b, _c, _d, _e;
  const capCustomPlatform = win.CapacitorCustomPlatform || null;
  const cap = win.Capacitor || {};
  const Plugins = cap.Plugins = cap.Plugins || {};
  const capPlatforms = win.CapacitorPlatforms;
  const defaultGetPlatform = () => {
    return capCustomPlatform !== null ? capCustomPlatform.name : getPlatformId(win);
  };
  const getPlatform = ((_a = capPlatforms === null || capPlatforms === void 0 ? void 0 : capPlatforms.currentPlatform) === null || _a === void 0 ? void 0 : _a.getPlatform) || defaultGetPlatform;
  const defaultIsNativePlatform = () => getPlatform() !== "web";
  const isNativePlatform = ((_b = capPlatforms === null || capPlatforms === void 0 ? void 0 : capPlatforms.currentPlatform) === null || _b === void 0 ? void 0 : _b.isNativePlatform) || defaultIsNativePlatform;
  const defaultIsPluginAvailable = (pluginName) => {
    const plugin = registeredPlugins.get(pluginName);
    if (plugin === null || plugin === void 0 ? void 0 : plugin.platforms.has(getPlatform())) {
      return true;
    }
    if (getPluginHeader(pluginName)) {
      return true;
    }
    return false;
  };
  const isPluginAvailable = ((_c = capPlatforms === null || capPlatforms === void 0 ? void 0 : capPlatforms.currentPlatform) === null || _c === void 0 ? void 0 : _c.isPluginAvailable) || defaultIsPluginAvailable;
  const defaultGetPluginHeader = (pluginName) => {
    var _a2;
    return (_a2 = cap.PluginHeaders) === null || _a2 === void 0 ? void 0 : _a2.find((h) => h.name === pluginName);
  };
  const getPluginHeader = ((_d = capPlatforms === null || capPlatforms === void 0 ? void 0 : capPlatforms.currentPlatform) === null || _d === void 0 ? void 0 : _d.getPluginHeader) || defaultGetPluginHeader;
  const handleError = (err) => win.console.error(err);
  const pluginMethodNoop = (_target, prop, pluginName) => {
    return Promise.reject(`${pluginName} does not have an implementation of "${prop}".`);
  };
  const registeredPlugins = /* @__PURE__ */ new Map();
  const defaultRegisterPlugin = (pluginName, jsImplementations = {}) => {
    const registeredPlugin = registeredPlugins.get(pluginName);
    if (registeredPlugin) {
      console.warn(`Capacitor plugin "${pluginName}" already registered. Cannot register plugins twice.`);
      return registeredPlugin.proxy;
    }
    const platform = getPlatform();
    const pluginHeader = getPluginHeader(pluginName);
    let jsImplementation;
    const loadPluginImplementation = async () => {
      if (!jsImplementation && platform in jsImplementations) {
        jsImplementation = typeof jsImplementations[platform] === "function" ? jsImplementation = await jsImplementations[platform]() : jsImplementation = jsImplementations[platform];
      } else if (capCustomPlatform !== null && !jsImplementation && "web" in jsImplementations) {
        jsImplementation = typeof jsImplementations["web"] === "function" ? jsImplementation = await jsImplementations["web"]() : jsImplementation = jsImplementations["web"];
      }
      return jsImplementation;
    };
    const createPluginMethod = (impl, prop) => {
      var _a2, _b2;
      if (pluginHeader) {
        const methodHeader = pluginHeader === null || pluginHeader === void 0 ? void 0 : pluginHeader.methods.find((m) => prop === m.name);
        if (methodHeader) {
          if (methodHeader.rtype === "promise") {
            return (options) => cap.nativePromise(pluginName, prop.toString(), options);
          } else {
            return (options, callback) => cap.nativeCallback(pluginName, prop.toString(), options, callback);
          }
        } else if (impl) {
          return (_a2 = impl[prop]) === null || _a2 === void 0 ? void 0 : _a2.bind(impl);
        }
      } else if (impl) {
        return (_b2 = impl[prop]) === null || _b2 === void 0 ? void 0 : _b2.bind(impl);
      } else {
        throw new CapacitorException(`"${pluginName}" plugin is not implemented on ${platform}`, ExceptionCode.Unimplemented);
      }
    };
    const createPluginMethodWrapper = (prop) => {
      let remove;
      const wrapper = (...args) => {
        const p = loadPluginImplementation().then((impl) => {
          const fn = createPluginMethod(impl, prop);
          if (fn) {
            const p2 = fn(...args);
            remove = p2 === null || p2 === void 0 ? void 0 : p2.remove;
            return p2;
          } else {
            throw new CapacitorException(`"${pluginName}.${prop}()" is not implemented on ${platform}`, ExceptionCode.Unimplemented);
          }
        });
        if (prop === "addListener") {
          p.remove = async () => remove();
        }
        return p;
      };
      wrapper.toString = () => `${prop.toString()}() { [capacitor code] }`;
      Object.defineProperty(wrapper, "name", {
        value: prop,
        writable: false,
        configurable: false
      });
      return wrapper;
    };
    const addListener = createPluginMethodWrapper("addListener");
    const removeListener = createPluginMethodWrapper("removeListener");
    const addListenerNative = (eventName, callback) => {
      const call = addListener({ eventName }, callback);
      const remove = async () => {
        const callbackId = await call;
        removeListener({
          eventName,
          callbackId
        }, callback);
      };
      const p = new Promise((resolve) => call.then(() => resolve({ remove })));
      p.remove = async () => {
        console.warn(`Using addListener() without 'await' is deprecated.`);
        await remove();
      };
      return p;
    };
    const proxy = new Proxy({}, {
      get(_, prop) {
        switch (prop) {
          case "$$typeof":
            return void 0;
          case "toJSON":
            return () => ({});
          case "addListener":
            return pluginHeader ? addListenerNative : addListener;
          case "removeListener":
            return removeListener;
          default:
            return createPluginMethodWrapper(prop);
        }
      }
    });
    Plugins[pluginName] = proxy;
    registeredPlugins.set(pluginName, {
      name: pluginName,
      proxy,
      platforms: /* @__PURE__ */ new Set([
        ...Object.keys(jsImplementations),
        ...pluginHeader ? [platform] : []
      ])
    });
    return proxy;
  };
  const registerPlugin2 = ((_e = capPlatforms === null || capPlatforms === void 0 ? void 0 : capPlatforms.currentPlatform) === null || _e === void 0 ? void 0 : _e.registerPlugin) || defaultRegisterPlugin;
  if (!cap.convertFileSrc) {
    cap.convertFileSrc = (filePath) => filePath;
  }
  cap.getPlatform = getPlatform;
  cap.handleError = handleError;
  cap.isNativePlatform = isNativePlatform;
  cap.isPluginAvailable = isPluginAvailable;
  cap.pluginMethodNoop = pluginMethodNoop;
  cap.registerPlugin = registerPlugin2;
  cap.Exception = CapacitorException;
  cap.DEBUG = !!cap.DEBUG;
  cap.isLoggingEnabled = !!cap.isLoggingEnabled;
  cap.platform = cap.getPlatform();
  cap.isNative = cap.isNativePlatform();
  return cap;
};
const initCapacitorGlobal = (win) => win.Capacitor = createCapacitor(win);
const Capacitor = /* @__PURE__ */ initCapacitorGlobal(typeof globalThis !== "undefined" ? globalThis : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : typeof global !== "undefined" ? global : {});
const registerPlugin = Capacitor.registerPlugin;
Capacitor.Plugins;
class WebPlugin {
  constructor(config) {
    this.listeners = {};
    this.windowListeners = {};
    if (config) {
      console.warn(`Capacitor WebPlugin "${config.name}" config object was deprecated in v3 and will be removed in v4.`);
      this.config = config;
    }
  }
  addListener(eventName, listenerFunc) {
    const listeners = this.listeners[eventName];
    if (!listeners) {
      this.listeners[eventName] = [];
    }
    this.listeners[eventName].push(listenerFunc);
    const windowListener = this.windowListeners[eventName];
    if (windowListener && !windowListener.registered) {
      this.addWindowListener(windowListener);
    }
    const remove = async () => this.removeListener(eventName, listenerFunc);
    const p = Promise.resolve({ remove });
    Object.defineProperty(p, "remove", {
      value: async () => {
        console.warn(`Using addListener() without 'await' is deprecated.`);
        await remove();
      }
    });
    return p;
  }
  async removeAllListeners() {
    this.listeners = {};
    for (const listener in this.windowListeners) {
      this.removeWindowListener(this.windowListeners[listener]);
    }
    this.windowListeners = {};
  }
  notifyListeners(eventName, data) {
    const listeners = this.listeners[eventName];
    if (listeners) {
      listeners.forEach((listener) => listener(data));
    }
  }
  hasListeners(eventName) {
    return !!this.listeners[eventName].length;
  }
  registerWindowListener(windowEventName, pluginEventName) {
    this.windowListeners[pluginEventName] = {
      registered: false,
      windowEventName,
      pluginEventName,
      handler: (event) => {
        this.notifyListeners(pluginEventName, event);
      }
    };
  }
  unimplemented(msg = "not implemented") {
    return new Capacitor.Exception(msg, ExceptionCode.Unimplemented);
  }
  unavailable(msg = "not available") {
    return new Capacitor.Exception(msg, ExceptionCode.Unavailable);
  }
  async removeListener(eventName, listenerFunc) {
    const listeners = this.listeners[eventName];
    if (!listeners) {
      return;
    }
    const index = listeners.indexOf(listenerFunc);
    this.listeners[eventName].splice(index, 1);
    if (!this.listeners[eventName].length) {
      this.removeWindowListener(this.windowListeners[eventName]);
    }
  }
  addWindowListener(handle) {
    window.addEventListener(handle.windowEventName, handle.handler);
    handle.registered = true;
  }
  removeWindowListener(handle) {
    if (!handle) {
      return;
    }
    window.removeEventListener(handle.windowEventName, handle.handler);
    handle.registered = false;
  }
}
const encode = (str) => encodeURIComponent(str).replace(/%(2[346B]|5E|60|7C)/g, decodeURIComponent).replace(/[()]/g, escape);
const decode = (str) => str.replace(/(%[\dA-F]{2})+/gi, decodeURIComponent);
class CapacitorCookiesPluginWeb extends WebPlugin {
  async getCookies() {
    const cookies = document.cookie;
    const cookieMap = {};
    cookies.split(";").forEach((cookie) => {
      if (cookie.length <= 0)
        return;
      let [key, value] = cookie.replace(/=/, "CAP_COOKIE").split("CAP_COOKIE");
      key = decode(key).trim();
      value = decode(value).trim();
      cookieMap[key] = value;
    });
    return cookieMap;
  }
  async setCookie(options) {
    try {
      const encodedKey = encode(options.key);
      const encodedValue = encode(options.value);
      const expires = `; expires=${(options.expires || "").replace("expires=", "")}`;
      const path = (options.path || "/").replace("path=", "");
      const domain = options.url != null && options.url.length > 0 ? `domain=${options.url}` : "";
      document.cookie = `${encodedKey}=${encodedValue || ""}${expires}; path=${path}; ${domain};`;
    } catch (error) {
      return Promise.reject(error);
    }
  }
  async deleteCookie(options) {
    try {
      document.cookie = `${options.key}=; Max-Age=0`;
    } catch (error) {
      return Promise.reject(error);
    }
  }
  async clearCookies() {
    try {
      const cookies = document.cookie.split(";") || [];
      for (const cookie of cookies) {
        document.cookie = cookie.replace(/^ +/, "").replace(/=.*/, `=;expires=${new Date().toUTCString()};path=/`);
      }
    } catch (error) {
      return Promise.reject(error);
    }
  }
  async clearAllCookies() {
    try {
      await this.clearCookies();
    } catch (error) {
      return Promise.reject(error);
    }
  }
}
registerPlugin("CapacitorCookies", {
  web: () => new CapacitorCookiesPluginWeb()
});
const readBlobAsBase64 = async (blob) => new Promise((resolve, reject) => {
  const reader = new FileReader();
  reader.onload = () => {
    const base64String = reader.result;
    resolve(base64String.indexOf(",") >= 0 ? base64String.split(",")[1] : base64String);
  };
  reader.onerror = (error) => reject(error);
  reader.readAsDataURL(blob);
});
const normalizeHttpHeaders = (headers = {}) => {
  const originalKeys = Object.keys(headers);
  const loweredKeys = Object.keys(headers).map((k) => k.toLocaleLowerCase());
  const normalized = loweredKeys.reduce((acc, key, index) => {
    acc[key] = headers[originalKeys[index]];
    return acc;
  }, {});
  return normalized;
};
const buildUrlParams = (params, shouldEncode = true) => {
  if (!params)
    return null;
  const output = Object.entries(params).reduce((accumulator, entry) => {
    const [key, value] = entry;
    let encodedValue;
    let item;
    if (Array.isArray(value)) {
      item = "";
      value.forEach((str) => {
        encodedValue = shouldEncode ? encodeURIComponent(str) : str;
        item += `${key}=${encodedValue}&`;
      });
      item.slice(0, -1);
    } else {
      encodedValue = shouldEncode ? encodeURIComponent(value) : value;
      item = `${key}=${encodedValue}`;
    }
    return `${accumulator}&${item}`;
  }, "");
  return output.substr(1);
};
const buildRequestInit = (options, extra = {}) => {
  const output = Object.assign({ method: options.method || "GET", headers: options.headers }, extra);
  const headers = normalizeHttpHeaders(options.headers);
  const type = headers["content-type"] || "";
  if (typeof options.data === "string") {
    output.body = options.data;
  } else if (type.includes("application/x-www-form-urlencoded")) {
    const params = new URLSearchParams();
    for (const [key, value] of Object.entries(options.data || {})) {
      params.set(key, value);
    }
    output.body = params.toString();
  } else if (type.includes("multipart/form-data")) {
    const form = new FormData();
    if (options.data instanceof FormData) {
      options.data.forEach((value, key) => {
        form.append(key, value);
      });
    } else {
      for (const key of Object.keys(options.data)) {
        form.append(key, options.data[key]);
      }
    }
    output.body = form;
    const headers2 = new Headers(output.headers);
    headers2.delete("content-type");
    output.headers = headers2;
  } else if (type.includes("application/json") || typeof options.data === "object") {
    output.body = JSON.stringify(options.data);
  }
  return output;
};
class CapacitorHttpPluginWeb extends WebPlugin {
  async request(options) {
    const requestInit = buildRequestInit(options, options.webFetchExtra);
    const urlParams = buildUrlParams(options.params, options.shouldEncodeUrlParams);
    const url = urlParams ? `${options.url}?${urlParams}` : options.url;
    const response = await fetch(url, requestInit);
    const contentType = response.headers.get("content-type") || "";
    let { responseType = "text" } = response.ok ? options : {};
    if (contentType.includes("application/json")) {
      responseType = "json";
    }
    let data;
    let blob;
    switch (responseType) {
      case "arraybuffer":
      case "blob":
        blob = await response.blob();
        data = await readBlobAsBase64(blob);
        break;
      case "json":
        data = await response.json();
        break;
      case "document":
      case "text":
      default:
        data = await response.text();
    }
    const headers = {};
    response.headers.forEach((value, key) => {
      headers[key] = value;
    });
    return {
      data,
      headers,
      status: response.status,
      url: response.url
    };
  }
  async get(options) {
    return this.request(Object.assign(Object.assign({}, options), { method: "GET" }));
  }
  async post(options) {
    return this.request(Object.assign(Object.assign({}, options), { method: "POST" }));
  }
  async put(options) {
    return this.request(Object.assign(Object.assign({}, options), { method: "PUT" }));
  }
  async patch(options) {
    return this.request(Object.assign(Object.assign({}, options), { method: "PATCH" }));
  }
  async delete(options) {
    return this.request(Object.assign(Object.assign({}, options), { method: "DELETE" }));
  }
}
registerPlugin("CapacitorHttp", {
  web: () => new CapacitorHttpPluginWeb()
});
const Preferences = registerPlugin("Preferences", {
  web: () => __vitePreload(() => import("./web.a2acd2ad.js"), true ? ["assets/web.a2acd2ad.js","assets/index.6081da41.js","assets/index.ad018a60.css"] : void 0).then((m) => new m.PreferencesWeb())
});
const name = "mogU";
const version = "1.2.0";
const description = "mogU";
const productName = "mogU";
const author = "Arayll <gmarayll@gmail.com>";
const scripts = {
  lint: "eslint --ext .js,.vue ./",
  format: 'prettier --write "**/*.{js,vue,scss,html,md,json}" --ignore-path .gitignore',
  test: 'echo "No test specified" && exit 0',
  dev: "quasar dev",
  build: "quasar build"
};
const dependencies = {
  "@capacitor/camera": "^5.0.7",
  "@capacitor/filesystem": "^5.1.4",
  "@capacitor/haptics": "^5.0.6",
  "@capacitor/keyboard": "^5.0.6",
  "@capacitor/preferences": "^5.0.6",
  "@capacitor/share": "^5.0.6",
  "@quasar/extras": "^1.16.4",
  "cordova-plugin-purchase": "^13.8.3",
  events: "^3.3.0",
  "highlight.js": "^11.8.0",
  "iframe-resizer": "^4.3.6",
  pinia: "^2.0.11",
  quasar: "^2.6.0",
  vue: "^3.0.0",
  "vue-router": "^4.0.0",
  "workbox-webpack-plugin": "^7.0.0"
};
const devDependencies = {
  "@quasar/app-vite": "^1.3.0",
  autoprefixer: "^10.4.2",
  eslint: "^8.10.0",
  "eslint-config-prettier": "^8.1.0",
  "eslint-plugin-vue": "^9.0.0",
  postcss: "^8.4.14",
  prettier: "^2.5.1"
};
const engines = {
  node: "^18 || ^16 || ^14.19",
  npm: ">= 6.13.4",
  yarn: ">= 1.21.1"
};
var packageJson = {
  name,
  version,
  description,
  productName,
  author,
  "private": true,
  scripts,
  dependencies,
  devDependencies,
  engines
};
const useEnvStore = defineStore("env", () => {
  const base_url = ref("https://my-gpt-api.azurewebsites.net/");
  const token = ref("");
  const version2 = ref("");
  function getVersion() {
    version2.value = packageJson.version;
  }
  function compareVersions(versionA, versionB) {
    const partsA = versionA.split(".").map(Number);
    const partsB = versionB.split(".").map(Number);
    for (let i = 0; i < 3; i++) {
      if (partsA[i] < partsB[i]) {
        return -1;
      } else if (partsA[i] > partsB[i]) {
        return 1;
      }
    }
    return 0;
  }
  return { base_url, token, version: version2, getVersion, compareVersions };
});
const getToken$1 = async () => {
  const { value } = await Preferences.get({ key: "token" });
  return value;
};
const getHeaders$1 = async () => {
  const token = await getToken$1();
  return {
    "Content-Type": "application/json",
    "Authorization": token
  };
};
const envStore$1 = useEnvStore();
async function userLoginApi(user) {
  const url = envStore$1.base_url + "login";
  try {
    let response = await fetch(url, {
      method: "POST",
      body: JSON.stringify(user)
    });
    response = await response.json();
    return response;
  } catch (error) {
    console.error(error);
  }
}
async function changePasswordApi(email, password, code) {
  const url = envStore$1.base_url + "change_password";
  const headers = await getHeaders$1();
  try {
    let response = await fetch(url, {
      method: "POST",
      headers,
      body: JSON.stringify({ email, password, code })
    });
    response = await response.json();
    return response;
  } catch (error) {
    console.error(error);
  }
}
async function getCodeApi(email, tel) {
  const url = envStore$1.base_url + "get_code";
  const headers = await getHeaders$1();
  try {
    let response = await fetch(url, {
      method: "POST",
      headers,
      body: JSON.stringify({ email, tel })
    });
    response = await response.json();
    return response;
  } catch (error) {
    console.error(error);
  }
}
async function userRegisterApi(email, tel, password, code) {
  const url = envStore$1.base_url + "register";
  const headers = await getHeaders$1();
  try {
    let response = await fetch(url, {
      method: "POST",
      headers,
      body: JSON.stringify({ email, tel, password, code })
    });
    response = await response.json();
    return response;
  } catch (error) {
    console.error(error);
  }
}
async function queryUserApi() {
  useUserStore();
  const url = envStore$1.base_url + "api/query_user";
  const headers = await getHeaders$1();
  const UserIdresult = await Preferences.get({ key: "UserId" });
  const user_id = JSON.parse(UserIdresult.value);
  try {
    let response = await fetch(url, {
      method: "POST",
      headers,
      body: JSON.stringify({
        user_id
      })
    });
    if (!response.ok) {
      let data = await response.json();
      if (response.status === 401 && data.error === "Unauthorized") {
        await Preferences.set({ key: "token", value: "" });
        throw new Error("Unauthorized");
      } else {
        throw new Error(`HTTP error! status: ${response.status}`);
      }
    } else {
      response = await response.json();
      return response;
    }
  } catch (error) {
    console.error(error);
  }
}
async function updateUserApi(user) {
  const url = envStore$1.base_url + "api/update_user";
  const headers = await getHeaders$1();
  try {
    let response = await fetch(url, {
      method: "POST",
      headers,
      body: JSON.stringify(user)
    });
    if (!response.ok) {
      let data = await response.json();
      if (response.status === 401 && data.error === "Unauthorized") {
        await Preferences.set({ key: "token", value: "" });
        throw new Error("Unauthorized");
      } else {
        throw new Error(`HTTP error! status: ${response.status}`);
      }
    } else {
      response = await response.json();
      return response;
    }
  } catch (error) {
    console.error(error);
  }
}
async function queryApiCallsApi() {
  const userStore2 = useUserStore();
  const url = envStore$1.base_url + "api/query_api_calls";
  let today = new Date();
  today.setUTCHours(0, 0, 0, 0);
  today = today.toISOString();
  const headers = await getHeaders$1();
  try {
    let response = await fetch(url, {
      method: "POST",
      headers,
      body: JSON.stringify({
        user_id: userStore2.UserId,
        start_date: today,
        end_date: today
      })
    });
    if (!response.ok) {
      let data = await response.json();
      if (response.status === 401 && data.error === "Unauthorized") {
        await Preferences.set({ key: "token", value: "" });
        throw new Error("Unauthorized");
      } else {
        throw new Error(`HTTP error! status: ${response.status}`);
      }
    } else {
      response = await response.json();
      return response;
    }
  } catch (error) {
    console.error(error);
  }
}
async function apiCallLimit() {
  const userStore2 = useUserStore();
  const url = envStore$1.base_url + "api/api_call_limit";
  const headers = await getHeaders$1();
  const user_id = await userStore2.UserId;
  try {
    let response = await fetch(url, {
      method: "POST",
      headers,
      body: JSON.stringify({ user_id })
    });
    if (!response.ok) {
      let data = await response.json();
      if (response.status === 401 && data.error === "Unauthorized") {
        await Preferences.set({ key: "token", value: "" });
        throw new Error("Unauthorized");
      } else {
        throw new Error(`HTTP error! status: ${response.status}`);
      }
    } else {
      response = await response.json();
      return response;
    }
  } catch (error) {
    console.error(error);
  }
}
const useUserStore = defineStore("user", () => {
  const UserId = ref("");
  const Username = ref("");
  const Email = ref("");
  const Tel = ref("");
  const Membership = ref({
    "Level": "",
    "StartDate": "",
    "EndDate": ""
  });
  const Property = ref(
    {
      "Coin": 0,
      "UncountToken": 0
    }
  );
  async function setUserInfo(user) {
    await Preferences.set({ key: "UserId", value: JSON.stringify(user["UserId"]) });
    await Preferences.set({ key: "Username", value: JSON.stringify(user.Username) });
    await Preferences.set({ key: "Email", value: JSON.stringify(user.Email) });
    await Preferences.set({ key: "Tel", value: JSON.stringify(user.Tel) });
    await Preferences.set({ key: "Membership", value: JSON.stringify(user.Membership) });
    await Preferences.set({ key: "Property", value: JSON.stringify(user.Property) });
    UserId.value = user["UserId"];
    Username.value = user.Username;
    Email.value = user.Email;
    Tel.value = user.Tel;
    Membership.value = user.Membership;
    Property.value = user.Property;
  }
  async function getUserInfo() {
    UserId.value = JSON.parse((await Preferences.get({ key: "UserId" })).value);
    const user = await queryUserApi();
    await setUserInfo(user);
    Username.value = JSON.parse((await Preferences.get({ key: "Username" })).value);
    Email.value = JSON.parse((await Preferences.get({ key: "Email" })).value);
    Tel.value = JSON.parse((await Preferences.get({ key: "Tel" })).value);
    const membershipValue = await Preferences.get({ key: "Membership" });
    Membership.value = JSON.parse(membershipValue.value);
    const propertyValue = await Preferences.get({ key: "Property" });
    Property.value = JSON.parse(propertyValue.value);
  }
  return { UserId, Username, Email, Tel, Membership, Property, setUserInfo, getUserInfo };
});
var github = "";
const getToken = async () => {
  const { value } = await Preferences.get({ key: "token" });
  return value;
};
const getHeaders = async () => {
  const token = await getToken();
  return {
    "Content-Type": "application/json",
    "Authorization": token
  };
};
const envStore = useEnvStore();
async function chatApi(data, handleDelta, stream) {
  var _a;
  const envStore2 = useEnvStore();
  useChatStore();
  const url = envStore2.base_url + "api/chat";
  const headers = await getHeaders();
  if (stream) {
    try {
      const response = await fetch(url, {
        method: "POST",
        headers,
        body: JSON.stringify(data)
      });
      if (!response.ok) {
        throw new Error(`HTTP error! status: ${response.status}`);
      }
      const reader = response.body.getReader();
      let text = "";
      while (true) {
        const { value, done } = await reader.read();
        if (done)
          break;
        text += new TextDecoder().decode(value);
        const lines = text.split("\n");
        text = "";
        for (const line of lines.slice(0, -1)) {
          if (line.startsWith("data:")) {
            const eventData = line.slice(5).trim();
            try {
              const parsedData = JSON.parse(eventData);
              const delta = (_a = parsedData.choices[0]) == null ? void 0 : _a.delta;
              const content = (delta == null ? void 0 : delta.content) || "";
              const created = parsedData == null ? void 0 : parsedData.created;
              const function_call = delta["function_call"] ? delta["function_call"] : "";
              const if_handle_delta = await handleDelta(content, function_call, created);
              if (!if_handle_delta) {
                break;
              }
            } catch (error) {
              console.error("Error parsing event data:", error);
            }
          }
        }
        text = lines[lines.length - 1];
      }
    } catch (error) {
      console.error(error);
    }
  } else {
    try {
      let response = await fetch(url, {
        method: "POST",
        headers,
        body: JSON.stringify(data)
      });
      if (!response.ok) {
        let data2 = await response.json();
        if (response.status === 401 && data2.error === "Unauthorized") {
          await Preferences.set({ key: "token", value: "" });
          throw new Error("Unauthorized");
        } else {
          throw new Error(`HTTP error! status: ${response.status}`);
        }
      } else {
        response = await response.json();
        return response;
      }
    } catch (error) {
      console.error(error);
    }
  }
}
async function subjectApi() {
  const envStore2 = useEnvStore();
  const userStore2 = useUserStore();
  const params = new URLSearchParams();
  await userStore2.UserId;
  params.append("user_id", userStore2.UserId);
  const headers = await getHeaders();
  const apiURL = `${envStore2.base_url}api/user_subjects?${params.toString()}`;
  try {
    let response = await fetch(apiURL, {
      method: "GET",
      headers
    });
    if (!response.ok) {
      let data = await response.json();
      if (response.status === 401 && data.error === "Unauthorized") {
        await Preferences.set({ key: "token", value: "" });
        throw new Error("Unauthorized");
      } else {
        throw new Error(`HTTP error! status: ${response.status}`);
      }
    } else {
      response = await response.json();
      return response;
    }
  } catch (error) {
    console.error(error);
  }
}
async function subjectAddApi(subject) {
  const envStore2 = useEnvStore();
  const url = envStore2.base_url + "api/add_subject";
  const userStore2 = useUserStore();
  const headers = await getHeaders();
  try {
    let response = await fetch(url, {
      method: "POST",
      headers,
      body: JSON.stringify({ UserId: userStore2.UserId, Subject: subject })
    });
    if (!response.ok) {
      let data = await response.json();
      if (response.status === 401 && data.error === "Unauthorized") {
        await Preferences.set({ key: "token", value: "" });
        throw new Error("Unauthorized");
      } else {
        throw new Error(`HTTP error! status: ${response.status}`);
      }
    } else {
      response = await response.json();
      return response;
    }
  } catch (error) {
    console.error(error);
  }
}
async function subjectChangeApi(subject) {
  const url = envStore.base_url + "api/change_subject";
  const headers = await getHeaders();
  try {
    let response = await fetch(url, {
      method: "POST",
      headers,
      body: JSON.stringify(subject)
    });
    if (!response.ok) {
      let data = await response.json();
      if (response.status === 401 && data.error === "Unauthorized") {
        await Preferences.set({ key: "token", value: "" });
        throw new Error("Unauthorized");
      } else {
        throw new Error(`HTTP error! status: ${response.status}`);
      }
    } else {
      response = await response.json();
      return response;
    }
  } catch (error) {
    console.error(error);
  }
}
async function subjectDelApi(subject) {
  const url = envStore.base_url + "api/del_subject";
  const headers = await getHeaders();
  try {
    let response = await fetch(url, {
      method: "POST",
      headers,
      body: JSON.stringify(subject)
    });
    if (!response.ok) {
      let data = await response.json();
      if (response.status === 401 && data.error === "Unauthorized") {
        await Preferences.set({ key: "token", value: "" });
        throw new Error("Unauthorized");
      } else {
        throw new Error(`HTTP error! status: ${response.status}`);
      }
    } else {
      response = await response.json();
      return response;
    }
  } catch (error) {
    console.error(error);
  }
}
async function subjectChatApi() {
  const envStore2 = useEnvStore();
  const chatStore = useChatStore();
  const params = new URLSearchParams();
  params.append("subject_id", chatStore.curr_subject.Id);
  const apiURL = `${envStore2.base_url}api/user_chats?${params.toString()}`;
  const headers = await getHeaders();
  try {
    let response = await fetch(apiURL, {
      method: "GET",
      headers
    });
    if (!response.ok) {
      let data = await response.json();
      if (response.status === 401 && data.error === "Unauthorized") {
        await Preferences.set({ key: "token", value: "" });
        throw new Error("Unauthorized");
      } else {
        throw new Error(`HTTP error! status: ${response.status}`);
      }
    } else {
      response = await response.json();
      return response === null ? [] : response;
    }
  } catch (error) {
    console.error(error);
  }
}
async function coinUsageApi(messages, model, functions) {
  const url = envStore.base_url + "api/coin_usage";
  const headers = await getHeaders();
  try {
    let response = await fetch(url, {
      method: "POST",
      headers,
      body: JSON.stringify({ messages, model, functions })
    });
    if (!response.ok) {
      let data = await response.json();
      if (response.status === 401 && data.error === "Unauthorized") {
        await Preferences.set({ key: "token", value: "" });
        throw new Error("Unauthorized");
      } else {
        throw new Error(`HTTP error! status: ${response.status}`);
      }
    } else {
      response = await response.json();
      return response;
    }
  } catch (error) {
    console.error(error);
  }
}
const userStore = useUserStore();
const useChatStore = defineStore("chat", () => {
  const curr_subject = ref({ "Id": "", "Subject": "", "UserId": userStore.UserId });
  const subjects = ref({});
  const chats = ref({});
  const api_calls = ref([]);
  const api_call_limit = ref({});
  ref({});
  ref({});
  const temp_text = ref({
    "text": "",
    "func_type": ""
  });
  const api_calls_group = computed(() => {
    let api_calls_group2 = {};
    if (api_calls.value != null) {
      api_calls.value.forEach((item) => {
        api_calls_group2[item["model"]] = item;
      });
    }
    return api_calls_group2;
  });
  async function getSubjects() {
    subjects.value = await subjectApi();
    if (curr_subject.value.Id !== "") {
      curr_subject.value.Subject = subjects.value[curr_subject.value.Id].Subject;
    }
  }
  async function getChats() {
    chats.value[curr_subject.value.Id] = await subjectChatApi();
    let data = chats.value;
    if (Array.isArray(data)) {
      data.sort((a, b) => a.CreatedAt - b.CreatedAt);
    }
    return data;
  }
  async function getApiCalls() {
    api_calls.value = await queryApiCallsApi();
  }
  async function getApiCallLimit() {
    api_call_limit.value = await apiCallLimit();
  }
  return { curr_subject, subjects, api_calls, api_calls_group, api_call_limit, getApiCallLimit, chats, temp_text, getSubjects, getChats, getApiCalls };
});
function useQuasar() {
  return inject(quasarKey);
}
export { Preferences as P, WebPlugin as W, useChatStore as a, subjectDelApi as b, subjectAddApi as c, useQuasar as d, useEnvStore as e, updateUserApi as f, chatApi as g, coinUsageApi as h, getCodeApi as i, userRegisterApi as j, changePasswordApi as k, userLoginApi as l, buildRequestInit as m, registerPlugin as r, subjectChangeApi as s, useUserStore as u };
